<?php

include('../../path.php');

require_once(ROOT_CONFIG);



    class regimen_fiscal

    {

        public function insert_regimen_fiscal($Id_Fk_Tipo_Persona, $Tipo_Persona, $Regimen_Tributario, $Fecha_De_Registro, $Usuario_Que_Registra, $Fecha_De_Modificacion, $Usuario_Que_Modifico)

        {

            require_once('../../log/controller/log.php');

            $Obj_log = new log();

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="INSERT INTO regimen_fiscal(Id_Fk_Tipo_Persona, Tipo_Persona, Regimen_Tributario, Fecha_De_Registro, Usuario_Que_Registra, Fecha_De_Modificacion, Usuario_Que_Modifico) VALUES ('$Id_Fk_Tipo_Persona', '$Tipo_Persona', '$Regimen_Tributario', '$Fecha_De_Registro', '$Usuario_Que_Registra', '$Fecha_De_Modificacion', '$Usuario_Que_Modifico') ";

            $conexion->query($consulta);

            $whatsmyid=$conexion->insert_id;

            $conexion->close();

            $_Tabla='regimen_fiscal';

            $_Evento_Log='registrar';

            $_Consulta = '"'.$consulta.'"';

            $Obj_log->insert_log_crud($_Tabla,$_Evento_Log,$_Consulta);

            return $whatsmyid;

        }



        public function get_regimen_fiscal($_Clausula_Fk,$_IdFk)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            if($_Clausula_Fk!='' && $_IdFk!=''){

                //$consulta="SELECT *,  count(*) as numregis FROM regimen_fiscal WHERE $_Clausula_Fk=$_IdFk ORDER BY Id_Regimen_Fiscal DESC";

                $consulta="SELECT count(*) as numregis FROM regimen_fiscal WHERE $_Clausula_Fk=$_IdFk";

            }else{

                //$consulta="SELECT *,  count(*) as numregis FROM regimen_fiscal ORDER BY Id_Regimen_Fiscal DESC";

                $consulta="SELECT count(*) as numregis FROM regimen_fiscal";

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function get_regimen_fiscalpg($inicio,$TAMANO_PAGINA,$_Clausula_Fk,$_IdFk)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            if($_Clausula_Fk!='' && $_IdFk!=''){

                $consulta="SELECT * FROM regimen_fiscal WHERE $_Clausula_Fk=$_IdFk ORDER BY Id_Regimen_Fiscal DESC";

            }else{

                $consulta="SELECT * FROM regimen_fiscal ORDER BY Id_Regimen_Fiscal DESC";

            }

            

            if ($TAMANO_PAGINA != "Todos") {

                $consulta .= " LIMIT $inicio, $TAMANO_PAGINA";

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function update_regimen_fiscal($Id_Regimen_Fiscal, $Id_Fk_Tipo_Persona, $Tipo_Persona, $Regimen_Tributario, $Fecha_De_Registro, $Usuario_Que_Registra, $Fecha_De_Modificacion, $Usuario_Que_Modifico)

        {

            require_once('../../log/controller/log.php');

            $Obj_log = new log();

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="UPDATE regimen_fiscal SET Id_Regimen_Fiscal='$Id_Regimen_Fiscal', Id_Fk_Tipo_Persona='$Id_Fk_Tipo_Persona', Tipo_Persona='$Tipo_Persona', Regimen_Tributario='$Regimen_Tributario', Fecha_De_Registro='$Fecha_De_Registro', Usuario_Que_Registra='$Usuario_Que_Registra', Fecha_De_Modificacion='$Fecha_De_Modificacion', Usuario_Que_Modifico='$Usuario_Que_Modifico' WHERE Id_Regimen_Fiscal = '$Id_Regimen_Fiscal'";

            $conexion->query($consulta);

            $rowaffected=$conexion->affected_rows;

            $conexion->close();

            $_Tabla='regimen_fiscal';

            $_Evento_Log='editar';

            $_Consulta = '"'.$consulta.'"';

            $Obj_log->insert_log_crud($_Tabla,$_Evento_Log,$_Consulta);

            return $rowaffected;

        }



        public function delete_regimen_fiscal($Id_Regimen_Fiscal)

        {

            require_once('../../log/controller/log.php');

            $Obj_log = new log();

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="DELETE FROM regimen_fiscal WHERE Id_Regimen_Fiscal='$Id_Regimen_Fiscal'";

            $conexion->query($consulta);

            $rowaffected=$conexion->affected_rows;

            $conexion->close();

            $_Tabla='regimen_fiscal';

            $_Evento_Log='eliminar';

            $_Consulta = '"'.$consulta.'"';

            $Obj_log->insert_log_crud($_Tabla,$_Evento_Log,$_Consulta);

            return $rowaffected;

        }



        //Funciones adicionales.

        public function getorderby_regimen_fiscal($Nombre,$Orderby,$_Clausula_Fk,$_IdFk)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            if($_Clausula_Fk!='' && $_IdFk!=''){

                //$consulta="SELECT *,  count(*) as numregis FROM regimen_fiscal WHERE $_Clausula_Fk=$_IdFk ORDER BY $Nombre $Orderby";

                $consulta="SELECT count(*) as numregis FROM regimen_fiscal WHERE $_Clausula_Fk=$_IdFk";

            }else{

                //$consulta="SELECT *,  count(*) as numregis FROM regimen_fiscal ORDER BY $Nombre $Orderby";

                $consulta="SELECT count(*) as numregis FROM regimen_fiscal";

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function getorderby_regimen_fiscalpg($Nombre,$Orderby,$inicio,$TAMANO_PAGINA,$_Clausula_Fk,$_IdFk)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            if($_Clausula_Fk!='' && $_IdFk!=''){

                $consulta="SELECT * FROM regimen_fiscal WHERE $_Clausula_Fk=$_IdFk ORDER BY $Nombre $Orderby";

            }else{

                $consulta="SELECT * FROM regimen_fiscal ORDER BY $Nombre $Orderby";

            }

            if ($TAMANO_PAGINA != "Todos") {

                $consulta .= " LIMIT $inicio, $TAMANO_PAGINA";

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function getbyid_regimen_fiscal($Id_Regimen_Fiscal)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT * FROM regimen_fiscal WHERE Id_Regimen_Fiscal='$Id_Regimen_Fiscal'";

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function get_regimen_fiscal_paginador_frm()

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT * FROM regimen_fiscal";

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function search_regimen_fiscal($Buscar,$_Clausula_Fk,$_IdFk)

        {

            require_once('../../log/controller/log.php');

            $Obj_log = new log();

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            if($_Clausula_Fk!='' && $_IdFk!=''){

                $consulta="SELECT *, count(*) as numregis FROM regimen_fiscal WHERE $_Clausula_Fk=$_IdFk AND (Id_Regimen_Fiscal LIKE '%$Buscar%' || Id_Fk_Tipo_Persona LIKE '%$Buscar%' || Tipo_Persona LIKE '%$Buscar%' || Regimen_Tributario LIKE '%$Buscar%' || Fecha_De_Registro LIKE '%$Buscar%' || Usuario_Que_Registra LIKE '%$Buscar%' || Fecha_De_Modificacion LIKE '%$Buscar%' || Usuario_Que_Modifico LIKE '%$Buscar%') ORDER BY Id_Regimen_Fiscal DESC";

                $consulta="SELECT count(*) as numregis FROM regimen_fiscal WHERE $_Clausula_Fk=$_IdFk AND (Id_Regimen_Fiscal LIKE '%$Buscar%' || Id_Fk_Tipo_Persona LIKE '%$Buscar%' || Tipo_Persona LIKE '%$Buscar%' || Regimen_Tributario LIKE '%$Buscar%' || Fecha_De_Registro LIKE '%$Buscar%' || Usuario_Que_Registra LIKE '%$Buscar%' || Fecha_De_Modificacion LIKE '%$Buscar%' || Usuario_Que_Modifico LIKE '%$Buscar%')";

            }else{

                //$consulta="SELECT *, count(*) as numregis FROM regimen_fiscal WHERE Id_Regimen_Fiscal LIKE '%$Buscar%' || Id_Fk_Tipo_Persona LIKE '%$Buscar%' || Tipo_Persona LIKE '%$Buscar%' || Regimen_Tributario LIKE '%$Buscar%' || Fecha_De_Registro LIKE '%$Buscar%' || Usuario_Que_Registra LIKE '%$Buscar%' || Fecha_De_Modificacion LIKE '%$Buscar%' || Usuario_Que_Modifico LIKE '%$Buscar%' ORDER BY Id_Regimen_Fiscal DESC";

                $consulta="SELECT count(*) as numregis FROM regimen_fiscal WHERE Id_Regimen_Fiscal LIKE '%$Buscar%' || Id_Fk_Tipo_Persona LIKE '%$Buscar%' || Tipo_Persona LIKE '%$Buscar%' || Regimen_Tributario LIKE '%$Buscar%' || Fecha_De_Registro LIKE '%$Buscar%' || Usuario_Que_Registra LIKE '%$Buscar%' || Fecha_De_Modificacion LIKE '%$Buscar%' || Usuario_Que_Modifico LIKE '%$Buscar%'";  

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            $_Tabla='regimen_fiscal';

            $_Evento_Log='busco:'.$Buscar;

            $_Consulta = '"'.$consulta.'"';

            $Obj_log->insert_log_consultas($_Tabla,$_Evento_Log,$_Consulta);

            return $Array_adapter;

        }



        public function search_regimen_fiscalpg($Buscar,$inicio,$TAMANO_PAGINA,$_Clausula_Fk,$_IdFk)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            if($_Clausula_Fk!='' && $_IdFk!=''){

                $consulta="SELECT * FROM regimen_fiscal WHERE $_Clausula_Fk=$_IdFk AND (Id_Regimen_Fiscal LIKE '%$Buscar%' || Id_Fk_Tipo_Persona LIKE '%$Buscar%' || Tipo_Persona LIKE '%$Buscar%' || Regimen_Tributario LIKE '%$Buscar%' || Fecha_De_Registro LIKE '%$Buscar%' || Usuario_Que_Registra LIKE '%$Buscar%' || Fecha_De_Modificacion LIKE '%$Buscar%' || Usuario_Que_Modifico LIKE '%$Buscar%') ORDER BY Id_Regimen_Fiscal DESC";

            }else{

                $consulta="SELECT * FROM regimen_fiscal WHERE Id_Regimen_Fiscal LIKE '%$Buscar%' || Id_Fk_Tipo_Persona LIKE '%$Buscar%' || Tipo_Persona LIKE '%$Buscar%' || Regimen_Tributario LIKE '%$Buscar%' || Fecha_De_Registro LIKE '%$Buscar%' || Usuario_Que_Registra LIKE '%$Buscar%' || Fecha_De_Modificacion LIKE '%$Buscar%' || Usuario_Que_Modifico LIKE '%$Buscar%' ORDER BY Id_Regimen_Fiscal DESC";

            }

            if ($TAMANO_PAGINA != "Todos") {

                $consulta .= " LIMIT $inicio, $TAMANO_PAGINA";

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function searchbyparameter_regimen_fiscal($Parametro,$Buscar)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT * FROM regimen_fiscal WHERE $Parametro LIKE '%$Buscar%' ORDER BY Id_Regimen_Fiscal DESC";

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }

  

        public function execute_regimen_fiscal($query)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $Array_adapter=$conexion->query($query);

            $conexion->close();

            return $Array_adapter;

        }



        public function update_field_regimen_fiscal($Field,$Value,$Id_Regimen_Fiscal)

        {

            require_once('../../log/controller/log.php');

            $Obj_log = new log();

            $Valueinto=strtoupper($Value);

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="UPDATE regimen_fiscal SET $Field='$Valueinto' WHERE Id_Regimen_Fiscal= '$Id_Regimen_Fiscal'";

            $conexion->query($consulta);

            $rowaffected=$conexion->affected_rows;

            $conexion->close();

            $_Tabla='regimen_fiscal';

            $_Evento_Log='editar';

            $_Consulta = '"'.$consulta.'"';

            $Obj_log->insert_log_crud($_Tabla,$_Evento_Log,$_Consulta);

            return $rowaffected;                          

        }



        public function update_field_front_regimen_fiscal($Field,$Value,$Id_Regimen_Fiscal)

        {

            require_once('../../log/controller/log.php');

            $Obj_log = new log();

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="UPDATE regimen_fiscal SET $Field='$Value' WHERE Id_Regimen_Fiscal= '$Id_Regimen_Fiscal'";

            $conexion->query($consulta);

            $rowaffected=$conexion->affected_rows;

            $conexion->close();

            $_Tabla='regimen_fiscal';

            $_Evento_Log='editar';

            $_Consulta = '"'.$consulta.'"';

            $Obj_log->insert_log_crud($_Tabla,$_Evento_Log,$_Consulta);

            return $rowaffected;                          

        }



}



?>